<?php


namespace Ardent\PicnicApi;


use GuzzleHttp\Client as GuzzleClient;
use GuzzleHttp\RequestOptions;

class Client
{
    const DEFAULT_COUNTRY_CODE = "NL";
    const DEFAULT_API_VERSION = "15";

    private GuzzleClient $client;

    /**
     * Client constructor.
     */
    public function __construct(string $username, string $password)
    {
        $this->client = new GuzzleClient([
            'base_uri' => $this->getApiUri(),
            'headers' => [
                'x-picnic-auth' => $this->authenticate($username, $password),
            ],
        ]);
    }

    private function authenticate(string $username, string $password): string
    {
        $client = new GuzzleClient([
            'base_uri' => $this->getApiUri(),
        ]);
        $data = [
            'key' => $username, // username
            'secret' => md5($password), // password
            'client_id' => 1,
        ];
        $result = $client->post('user/login', [
            RequestOptions::JSON => $data,
        ]);
//        $body = json_decode($result->getBody()->getContents(), true);
//        $userId = $body['user_id'];
//        $meta = json_decode(base64_decode($result->getHeader('picnic-meta-info')[0]))

        return $result->getHeader('x-picnic-auth')[0];
    }

    private static function getBaseUri(): string
    {
        return sprintf('https://storefront-prod.%s.picnicinternational.com',
            self::DEFAULT_COUNTRY_CODE
        );
    }

    private static function getApiUri(): string
    {
        return sprintf('%s/api/%s/',
            self::getBaseUri(),
            self::DEFAULT_API_VERSION
        );
    }

    /**
     * @param string $imageId
     * @param string $size one of tiny/small/medium/large/extra-large
     *
     * @return string
     */
    public static function getImageUri(string $imageId, string $size): string
    {
        return sprintf('%s/static/images/%s/%s.png',
            self::getBaseUri(),
            $imageId,
            $size
        );
    }

    public function post(string $url, array $data): array
    {
        $data = $this->client->post($url, [
            RequestOptions::JSON => $data,
        ]);

        return json_decode($data->getBody()->getContents(), true);
    }

    public function get(string $url): array
    {
        $data = $this->client->get($url);

        return json_decode($data->getBody()->getContents(), true);
    }
}