<?php


namespace Ardent\PicnicApi\Objects;


class Order extends AbstractApiObject
{
    /**
     * Order constructor.
     */
    public function __construct(
        private string $id,
        private array $items,
        private array $deliverySlots,
        private array $selectedSlot,
        private int $totalCount,
        private int $totalPrice,
        private int $checkoutTotalPrice,
    )
    {
    }

    static public function getType(): string
    {
        return 'ORDER';
    }

    static public function fromApi(array $apiObject): AbstractApiObject
    {
        return new self(
            $apiObject['id'],
            ApiListTransformer::getObjects($apiObject['items']),
            $apiObject['delivery_slots'] ?? [],
            $apiObject['selected_slot'] ?? [],
            $apiObject['total_count'] ?? -1,
            $apiObject['total_price'],
            $apiObject['checkout_total_price'],
        );
    }

    /**
     * @return string
     */
    public function getId(): string
    {
        return $this->id;
    }

    /**
     * @return OrderLine[]
     */
    public function getItems(): array
    {
        return $this->items;
    }

    /**
     * @return array
     */
    public function getDeliverySlots(): array
    {
        return $this->deliverySlots;
    }

    /**
     * @return array
     */
    public function getSelectedSlot(): array
    {
        return $this->selectedSlot;
    }

    /**
     * @return int
     */
    public function getTotalCount(): int
    {
        return $this->totalCount;
    }

    /**
     * @return int
     */
    public function getTotalPrice(): int
    {
        return $this->totalPrice;
    }

    /**
     * @return int
     */
    public function getCheckoutTotalPrice(): int
    {
        return $this->checkoutTotalPrice;
    }
}