<?php


namespace Ardent\PicnicApi\Objects;


use Ardent\PicnicApi\Client;

class OrderArticle extends AbstractApiObject
{
    /**
     * OrderArticle constructor.
     */
    public function __construct(
        private string $id,
        private string $name,
        private array $imageIds,
        private string $unitQuantity,
        private int $price,
        private int $maxCount,
    )
    {
    }

    static public function getType(): string
    {
        return 'ORDER_ARTICLE';
    }

    static public function fromApi(array $apiObject): AbstractApiObject
    {
        return new self(
            $apiObject['id'],
            $apiObject['name'],
            $apiObject['image_ids'],
            $apiObject['unit_quantity'],
            $apiObject['price'],
            $apiObject['max_count'],
        );
    }

    /**
     * @return string
     */
    public function getId(): string
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @param string $size one of tiny/small/medium/large/extra-large
     *
     * @return string[]
     */
    public function getImageUrls(string $size = 'medium'): array
    {
        return array_map(function ($id) use ($size) {
            return Client::getImageUri($id, $size);
        }, $this->imageIds);
    }

    /**
     * @return string
     */
    public function getUnitQuantity(): string
    {
        return $this->unitQuantity;
    }

    /**
     * @return int
     */
    public function getPrice(): int
    {
        return $this->price;
    }

    /**
     * @return int
     */
    public function getMaxCount(): int
    {
        return $this->maxCount;
    }
}