<?php


namespace Ardent\PicnicApi\Objects;


use Ardent\PicnicApi\Client;

class SingleArticle extends AbstractApiObject
{
    static public function getType(): string
    {
        return 'SINGLE_ARTICLE';
    }

    /**
     * SingleArticle constructor.
     */
    public function __construct(
        private string $id,
        private string $name,
        private int $price,
        private int $displayPrice,
        private string $imageId,
        private int $maxCount,
        private string $unitQuantity,
        private string $unitQuantitySub,
        private array $decorators,
    )
    {
    }

    static public function fromApi(array $apiObject): self
    {
        return new self(
            $apiObject['id'],
            $apiObject['name'],
            $apiObject['price'] ?? 0,
            $apiObject['display_price'],
            $apiObject['image_id'],
            $apiObject['max_count'],
            $apiObject['unit_quantity'],
            $apiObject['unit_quantity_sub'] ?? 'n/a',
            $apiObject['decorators']
        );
    }

    /**
     * @return string
     */
    public function getId(): string
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @return int
     */
    public function getPrice(): float
    {
        return $this->price / 100.0;
    }

    /**
     * @return int
     */
    public function getDisplayPrice(): float
    {
        return $this->displayPrice / 100.0;
    }

    /**
     * @return string
     */
    public function getImageId(): string
    {
        return $this->imageId;
    }

    public function getImageUrl(string $size = 'medium'): string
    {
        return Client::getImageUri($this->imageId, $size);
    }

    /**
     * @return int
     */
    public function getMaxCount(): int
    {
        return $this->maxCount;
    }

    /**
     * @return string
     */
    public function getUnitQuantity(): string
    {
        return $this->unitQuantity;
    }

    /**
     * @return string
     */
    public function getUnitQuantitySub(): string
    {
        return $this->unitQuantitySub;
    }

    /**
     * @return array
     */
    public function getDecorators(): array
    {
        return $this->decorators;
    }
}